@@ -1,11 +1,14 @@
 import json
 from pathlib import Path
 
-ASTRAEA_URL = 'https://eod-catalog-svc-prod.astraea.earth'
-MLHUB_URL = 'https://api.radiant.earth/mlhub/v1/'
-
 TEST_DATA = Path(__file__).parent / 'data'
 
+STAC_URLS = {
+    "PLANETARY-COMPUTER": "https://planetarycomputer.microsoft.com/api/stac/v1",
+    "EARTH-SEARCH": "https://earth-search.aws.element84.com/v0",
+    "MLHUB": "https://api.radiant.earth/mlhub/v1",
+}
+
 
 def read_data_file(file_name: str, mode='r', parse_json=False):
     file_path = TEST_DATA / file_name
@@ -14,6 +17,3 @@ def read_data_file(file_name: str, mode='r', parse_json=False):
             return json.load(src)
         else:
             return src.read()
-
-
-ASTRAEA_API_PATH = str(TEST_DATA / 'astraea_api.json')
